The django-analytical package was originally written by `Joost Cassee`_
and is now maintained by the `Jazzband community`_, with contributions
from `Eric Davis`_, `Paul Oswald`_, `Uros Trebec`_, `Steven Skoczen`_,
`Pi Delport`_, `Sandra Mau`_, `Simon Ye`_, `Tinnet Coronam`_,
`Philippe O. Wagner`_, `Max Arnold`_ , `Martín Gaitán`_, `Craig Bruce`_,
`Peter Bittner`_, `Scott Adams`_, `Eric Amador`_, `Alexandre Pocquet`_,
`Brad Pitcher`_, `Hugo Osvaldo Barrera`_, `Nikolay Korotkiy`_,
`Steve Schwarz`_, `Aleck Landgraf`_, `Marc Bourqui`_,
`Diederik van der Boor`_, `Matthäus G. Chajdas`_, `Scott Karlin`_
and others.

Included Javascript code snippets for integration of the analytics
services were written by the respective service providers.

The application was inspired by and uses ideas from Analytical_, Joshua
Krall's all-purpose analytics front-end for Rails.

The work on Crazy Egg was made possible by `Bateau Knowledge`_.
The work on Intercom was made possible by `GreenKahuna`_.

.. _`Joost Cassee`: https://github.com/jcassee
.. _`Jazzband community`: https://jazzband.co/
.. _`Eric Davis`: https://github.com/edavis
.. _`Paul Oswald`: https://github.com/poswald
.. _`Uros Trebec`: https://github.com/failedguidedog
.. _`Steven Skoczen`: https://github.com/skoczen
.. _`Pi Delport`: https://github.com/pjdelport
.. _`Sandra Mau`: https://github.com/xthepoet
.. _`Simon Ye`: https://github.com/yesimon
.. _`Tinnet Coronam`: https://github.com/tinnet
.. _`Philippe O. Wagner`: mailto:admin@arteria.ch
.. _`Max Arnold`: https://github.com/max-arnold
.. _`Martín Gaitán`: https://github.com/mgaitan
.. _`Craig Bruce`: https://github.com/craigbruce
.. _`Peter Bittner`: https://github.com/bittner
.. _`Scott Adams`: https://github.com/7wonders
.. _`Eric Amador`: https://github.com/amadornimbis
.. _`Alexandre Pocquet`: https://github.com/apocquet
.. _`Brad Pitcher`: https://github.com/brad
.. _`Hugo Osvaldo Barrera`: https://github.com/hobarrera
.. _`Nikolay Korotkiy`: https://github.com/sikmir
.. _`Steve Schwarz`: https://github.com/saschwarz
.. _`Aleck Landgraf`: https://github.com/alecklandgraf
.. _`Marc Bourqui`: https://github.com/mbourqui
.. _`Diederik van der Boor`: https://github.com/vdboor
.. _`Matthäus G. Chajdas`: https://github.com/Anteru
.. _`Analytical`: https://github.com/jkrall/analytical
.. _`Bateau Knowledge`: http://www.bateauknowledge.nl/
.. _`GreenKahuna`: http://www.greenkahuna.com/
.. _`Scott Karlin`: https://github.com/sckarlin
